==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/order/orders_status.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	orders_status.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ERROR_REMOVE_DEFAULT_ORDER_STATUS' => 'Fehler: Der Standard-Bestellstatus kann nicht gelöscht werden. Bitte definieren Sie einen neuen Standard-Bestellstatus und wiederholen Sie den Vorgang.',
	'ERROR_REMOVE_INVOICE_MAIL_ORDER_STATUS' => 'Fehler: Dieser Bestellstatus kann nicht gelöscht werden. Auf diesen Bestellstatus werden Bestellungen gesetzt, wenn eine Rechnung per E-Mail versendet wurde.',
	'ERROR_REMOVE_INVOICE_ORDER_STATUS' => 'Fehler: Dieser Bestellstatus kann nicht gelöscht werden. Auf diesen Bestellstatus werden Bestellungen gesetzt, wenn eine Rechnung erstellt wurde.',
	'ERROR_STATUS_USED_IN_HISTORY' => 'Fehler: Dieser Bestellstatus wird zur Zeit noch in der Bestellhistorie verwendet.',
	'ERROR_STATUS_USED_IN_ORDERS' => 'Fehler: Dieser Bestellstatus wird zur Zeit noch bei den Bestellungen verwendet.',
	'HEADING_TITLE' => 'Bestellstatus',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_ORDERS_STATUS' => 'Bestellstatus',
	'TEXT_COLOR' => 'Farbe',
	'TEXT_INFO_DELETE_INTRO' => 'Sind Sie sicher, dass Sie diesen Bestellstatus löschen möchten?',
	'TEXT_INFO_EDIT_INTRO' => 'Bitte führen Sie alle notwendigen Änderungen durch.',
	'TEXT_INFO_HEADING_DELETE_ORDERS_STATUS' => 'Bestellstatus löschen',
	'TEXT_INFO_HEADING_EDIT_ORDERS_STATUS' => 'Bestellstatus bearbeiten',
	'TEXT_INFO_HEADING_NEW_ORDERS_STATUS' => 'Neuer Bestellstatus',
	'TEXT_INFO_INSERT_INTRO' => 'Bitte geben Sie den neuen Bestellstatus mit allen relevanten Daten ein.',
	'TEXT_INFO_ORDERS_STATUS_NAME' => 'Bestellstatus:',
	'TEXT_PREVIEW' => 'Vorschau',
	'TEXT_SELECTCOLOR' => 'Farbe ändern',
	'TEXT_STORNO' => 'feststehend',
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/order/orders_status.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	orders_status.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ERROR_REMOVE_DEFAULT_ORDER_STATUS' => 'Fehler: Der Standard-Bestellstatus kann nicht gelöscht werden. Bitte definiere einen neuen Standard-Bestellstatus und wiederhole den Vorgang.',
	'ERROR_REMOVE_INVOICE_MAIL_ORDER_STATUS' => 'Fehler: Dieser Bestellstatus kann nicht gelöscht werden. Auf diesen Bestellstatus werden Bestellungen gesetzt, wenn eine Rechnung per E-Mail versendet wurde.',
	'ERROR_REMOVE_INVOICE_ORDER_STATUS' => 'Fehler: Dieser Bestellstatus kann nicht gelöscht werden. Auf diesen Bestellstatus werden Bestellungen gesetzt, wenn eine Rechnung erstellt wurde.',
	'ERROR_STATUS_USED_IN_HISTORY' => 'Fehler: Dieser Bestellstatus wird zur Zeit noch in der Bestellhistorie verwendet.',
	'ERROR_STATUS_USED_IN_ORDERS' => 'Fehler: Dieser Bestellstatus wird zur Zeit noch bei den Bestellungen verwendet.',
	'HEADING_TITLE' => 'Bestellstatus',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_ORDERS_STATUS' => 'Bestellstatus',
	'TEXT_COLOR' => 'Farbe',
	'TEXT_INFO_DELETE_INTRO' => 'Bist du sicher, dass du diesen Bestellstatus löschen möchtest?',
	'TEXT_INFO_EDIT_INTRO' => 'Bitte führe alle notwendigen Änderungen durch.',
	'TEXT_INFO_HEADING_DELETE_ORDERS_STATUS' => 'Bestellstatus löschen',
	'TEXT_INFO_HEADING_EDIT_ORDERS_STATUS' => 'Bestellstatus bearbeiten',
	'TEXT_INFO_HEADING_NEW_ORDERS_STATUS' => 'Neuer Bestellstatus',
	'TEXT_INFO_INSERT_INTRO' => 'Bitte gib den neuen Bestellstatus mit allen relevanten Daten ein.',
	'TEXT_INFO_ORDERS_STATUS_NAME' => 'Bestellstatus:',
	'TEXT_PREVIEW' => 'Vorschau',
	'TEXT_SELECTCOLOR' => 'Farbe ändern',
	'TEXT_STORNO' => 'feststehend',
);
